@@ -1,5 +1,5 @@
 package Search::QS;
-$Search::QS::VERSION = '0.02';
+$Search::QS::VERSION = '0.03';
 use strict;
 use warnings;
 
@@ -66,7 +66,7 @@ Search::QS - A converter between query string URI and search query
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -86,9 +86,9 @@ This module converts a query string like This
 
 into perl objects which rappresent a search.
 
-In L</"filters__"> there are all flt (filter) elements.
+In L</"filters()"> there are all flt (filter) elements.
 
-In L</"options__"> there are query options like limit, start and sorting.
+In L</"options()"> there are query options like limit, start and sorting.
 
 =head1 METHODS
 
@@ -105,12 +105,12 @@ Return an instance of L<Search::QS::Options>
 $perl_struct is an HASHREF which represents a query string like
 the one returned by L<URI::Encode/"url_params_mixed">.
 It parses the $perl_struct and fills related objects in
-L</"filters__"> and L</"options__">
+L</"filters()"> and L</"options()">
 
 =head2 to_qs()
 
-    Return a query string which represents current state of L<filters__> and L<options__>
-elements
+Return a query string which represents current state of L<filters()>
+and L<options()> elements
 
 =head1 Examples
 
@@ -142,17 +142,17 @@ should be converted into
 
   ( (FirstName = Foo) OR (LastName = Bar) )
 
-=item ?flt[c:one]=1&flt[c:one]=$and:1&flt[d:one]=2&flt[d:one]=$and:1&flt[c:two]=2&flt[c:two]=$and:2&flt[d:two]=3&flt[d:two]=$op:>&flt[d:two]=$and:2&flt[d:three]=10
+=item C<?flt[c:one]=1&flt[c:one]=$and:1&flt[d:one]=2&flt[d:one]=$and:1&flt[c:two]=2&flt[c:two]=$and:2&flt[d:two]=3&flt[d:two]=$op:!=&flt[d:two]=$and:2&flt[d:three]=10>
 
 should be converted into
 
-  (d = 10) AND  ( (c = 1) AND (d = 2) )  OR  ( (c = 2) AND (d > 3) )
+  (d = 10) AND  ( (c = 1) AND (d = 2) )  OR  ( (c = 2) AND (d != 3) )
 
 =back
 
 =head1 SEE ALSO
 
-L<Seach::QS::Filters>, L<Seach::QS::Filter>, L<Seach::QS::Options>
+L<Search::QS::Filters>, L<Search::QS::Filter>, L<Search::QS::Options>
 
 =head1 AUTHOR
 
