@@ -1,5 +1,5 @@
 package Search::QS::Options;
-$Search::QS::Options::VERSION = '0.02';
+$Search::QS::Options::VERSION = '0.03';
 use v5.14;
 use strict;
 use warnings;
@@ -25,7 +25,7 @@ sub parse() {
 
     $s->reset();
 
-    while (my ($k,$v) = each $struct) {
+    while (my ($k,$v) = each %$struct) {
         given($k) {
 			when ('start')   { $s->start($v) }
 			when ('limit')   { $s->limit($v) }
@@ -90,7 +90,7 @@ Search::QS::Options - Options query search like limits, start and sort
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
